@@ -37,7 +37,7 @@
 
 #include "config_nc.h"
 
-static char rcsid[] not_used ={"$Id: Dattr.cc 11906 2005-08-08 19:51:43Z root $"};
+static char rcsid[] not_used ={"$Id: Dattr.cc 12258 2005-09-27 19:38:28Z jimg $"};
 
 #include "Dnetcdf.h"
 #include "Dncx.h"
@@ -360,50 +360,53 @@ nc_inq_att(int cdfid, int varid, const char *name,
 	if (p == attr.attr_end())
 	    return NC_ENOTATT;
 
-	if (datatypep == 0 || lenp == 0)
+	if (datatypep == 0 && lenp == 0)
 	    return NC_NOERR;
 
 	string attrV = attr.get_attr(p);
 	AttrType attrT = attr.get_attr_type(p);
 
-	*lenp = static_cast<size_t>(attr.get_attr_num(p));
+	if (lenp) 
+            *lenp = static_cast<size_t>(attr.get_attr_num(p));
 
 	switch (attrT) {
 	  case Attr_byte:
-	    *datatypep =  NC_BYTE;
+	    if(datatypep) *datatypep =  NC_BYTE;
 	    break;
 	  case Attr_int32:
 	  case Attr_uint32:
-	    *datatypep =  NC_LONG;
+	    if(datatypep) *datatypep =  NC_LONG;
 	    break;
 	  case Attr_int16:
 	  case Attr_uint16:
-	    *datatypep =  NC_SHORT;
+	    if(datatypep) *datatypep =  NC_SHORT;
 	    break;
 	  case Attr_float32:
-	    *datatypep =  NC_FLOAT;
+	    if(datatypep) *datatypep =  NC_FLOAT;
 	    break;
 	  case Attr_float64:
-	    *datatypep =  NC_DOUBLE;
+	    if(datatypep) *datatypep =  NC_DOUBLE;
 	    break;
 	  case Attr_string: {
-	      *datatypep =  NC_CHAR;
-	      *lenp = 0;
-	      // string lenght is the total number of bytes plus
-	      // terminating character. There is a '\n' at the end of each
-	      // string, but a '\0' at the end of the attibutes.
-	      unsigned int attr_siz = attr.get_attr_num(p);
-
-	      for (unsigned int i = 0; i < attr_siz; i++){
-		  attrV = attr.get_attr(p, i);
-		  *lenp +=  attrV.length() - 1; // EOS included, quotes removed  
-	      }
-	      // single string (coming from a netCDF server) remove EOS
-	      // for compatibility
-	      if (attr.get_attr_num(p) == 1)
-		  *lenp -= 1;
-	  }
+	    if(datatypep) *datatypep =  NC_CHAR;
+	    if(lenp) {
+		*lenp = 0;
+		// string lenght is the total number of bytes plus
+		// terminating character. There is a '\n' at the end of each
+		// string, but a '\0' at the end of the attibutes.
+		unsigned int attr_siz = attr.get_attr_num(p);
+		
+		for (unsigned int i = 0; i < attr_siz; i++){
+		    attrV = attr.get_attr(p, i);
+		    *lenp +=  attrV.length() - 1; // EOS included, quotes removed  
+		}
+		// single string (coming from a netCDF server) remove EOS
+		// for compatibility
+		if (attr.get_attr_num(p) == 1)
+		    *lenp -= 1;
+	    }
 	    break;
+	  }
 
 	  default:
 	    return NC_ENOTATT;
