@@ -39,7 +39,7 @@
 
 #include "config_nc.h"
 
-static char rcsid[] not_used = {"$Id: NCConnect.cc 11983 2005-08-18 21:16:31Z jimg $"};
+static char rcsid[] not_used = {"$Id: NCConnect.cc 13108 2006-02-01 19:17:04Z jimg $"};
 
 #include "netcdf.h"
 
@@ -134,12 +134,20 @@ compute_string_attr_length(AttrTable &attr, AttrTable::Attr_iter &p)
     @param name A filename or URL. */
 NCConnect::NCConnect(const string &name, const ClientParams &cp) 
     : AISConnect(name), d_client_params(cp), d_global_attributes(0),
-      d_factory(0),
+      d_factory(0), d_constrained_dds(0), d_translated_dds(0), 
       d_ncid(-1), d_nvars(-1), d_recdim(-1), d_ndims(0)
+      // Note the trick above where d_factory is initialized to null and null
+      // is passed to the two DDS objects. This prevents this ctor from trying
+      // to call the default ctor for DDS (which doesn't exist). In the body 
+      // of the ctor I make the real Factory and pass it to the two DDS 
+      // objects. Using the new operator in these initialization code 
+      // does not work. 1/27/06
 {
+#if 1
     d_factory = new NCTypeFactory;
     d_constrained_dds.set_factory(d_factory);
     d_translated_dds.set_factory(d_factory);
+#endif
 }	
 
 NCConnect::~NCConnect()
