@@ -1,4 +1,29 @@
 
+// -*- mode: c++; c-basic-offset:4 -*-
+
+// This file is part of libdap, A C++ implementation of the OPeNDAP Data
+// Access Protocol.
+
+// Copyright (c) 2002,2003,2005 OPeNDAP, Inc.
+// Author: James Gallagher <jgallagher@opendap.org>
+//         Reza Nekovei <reza@intcomm.net>
+//
+// This library is free software; you can redistribute it and/or
+// modify it under the terms of the GNU Lesser General Public
+// License as published by the Free Software Foundation; either
+// version 2.1 of the License, or (at your option) any later version.
+// 
+// This library is distributed in the hope that it will be useful,
+// but WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+// Lesser General Public License for more details.
+// 
+// You should have received a copy of the GNU Lesser General Public
+// License along with this library; if not, write to the Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+//
+// You can contact OPeNDAP, Inc. at PO Box 112, Saunderstown, RI. 02874-0112.
+
 // (c) COPYRIGHT OPeNDAP, Inc 2004
 // Please read the full copyright statement in the file COPYRIGHT.
 //
@@ -9,7 +34,7 @@
 
 #include "config_nc.h"
 
-static char rcsid[] not_used ={"$Id: nc_util.cc,v 1.20 2005/04/11 18:38:20 jimg Exp $"};
+static char rcsid[] not_used ={"$Id: nc_util.cc 11906 2005-08-08 19:51:43Z root $"};
 
 #include <sstream>
 
